# FundingContributorV20

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**contributor_orcid** | [**ContributorOrcidV20**](ContributorOrcidV20.md) |  | [optional] 
**credit_name** | [**CreditNameV20**](CreditNameV20.md) |  | [optional] 
**contributor_email** | [**ContributorEmailV20**](ContributorEmailV20.md) |  | [optional] 
**contributor_attributes** | [**FundingContributorAttributesV20**](FundingContributorAttributesV20.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

